==> cpl-plugin-kmos_1.2.8+dfsg.orig.tar.xz: kmos-1.2.8/kmos/kmo_priv_make_image.h <==
/* $Id: kmo_priv_make_image.h,v 1.1.1.1 2012-01-18 09:31:59 yjung Exp $
 *
 * This file is part of the KMOS Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: yjung $
 * $Date: 2012-01-18 09:31:59 $
 * $Revision: 1.1.1.1 $
 * $Name: not supported by cvs2svn $
 */

#ifndef KMOS_PRIV_MAKE_IMAGE_H
#define KMOS_PRIV_MAKE_IMAGE_H

/*-----------------------------------------------------------------------------
 *                              Includes
 *----------------------------------------------------------------------------*/

#include <cpl.h>

/*------------------------------------------------------------------------------
 *                        Prototypes
 *----------------------------------------------------------------------------*/

cpl_vector* kmo_identify_slices_with_oh(cpl_vector *spec_data_in,
                                   cpl_vector *spec_lambda_in,
                                   cpl_vector *ranges,
                                   double threshold,
                                   int ifu_crpix,
                                   double ifu_crval,
                                   double ifu_cdelt,
                                   int size_ifu);

int kmo_priv_is_below_threshold(double threshold,
                                   cpl_vector *spec_data_out,
                                   int index);

#endif

==> cpl-plugin-kmos_1.3.17+dfsg.orig.tar.xz: kmos-1.3.17/kmos/kmo_priv_make_image.h <==
/*
 * This file is part of the KMOS Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef KMOS_PRIV_MAKE_IMAGE_H
#define KMOS_PRIV_MAKE_IMAGE_H

/*-----------------------------------------------------------------------------
 *                              Includes
 *----------------------------------------------------------------------------*/

#include <cpl.h>

/*------------------------------------------------------------------------------
 *                              Prototypes
 *----------------------------------------------------------------------------*/

cpl_vector * kmo_identify_slices_with_oh(
        cpl_vector  *   spec_data_in,
        cpl_vector  *   spec_lambda_in,
        cpl_vector  *   ranges,
        double          threshold,
        double          ifu_crpix,
        double          ifu_crval,
        double          ifu_cdelt,
        int             size_ifu) ;

#endif
